[Python-checkins] [3.7] bpo-39136: Fixed typos (GH-17720)

Terry Jan Reedy webhook-mailer at python.org
Sun Dec 29 01:41:14 EST 2019


https://github.com/python/cpython/commit/d7947280a4ba9dc652c3fac22946466338ec6999
commit: d7947280a4ba9dc652c3fac22946466338ec6999
branch: 3.7
author: Terry Jan Reedy <tjreedy at udel.edu>
committer: GitHub <noreply at github.com>
date: 2019-12-29T01:40:49-05:00
summary:

[3.7] bpo-39136: Fixed typos (GH-17720)

focusses -> focuses; follwing -> following; Excape -> Escape.

(cherry picked from commit 6c7bb38)

files:
M Doc/faq/programming.rst
M Lib/idlelib/NEWS.txt
M Lib/tkinter/tix.py

diff --git a/Doc/faq/programming.rst b/Doc/faq/programming.rst
index a8aaebf7558ee..270f57d8b8093 100644
--- a/Doc/faq/programming.rst
+++ b/Doc/faq/programming.rst
@@ -1026,7 +1026,7 @@ That's a tough one, in general.  First, here are a list of things to
 remember before diving further:
 
 * Performance characteristics vary across Python implementations.  This FAQ
-  focusses on :term:`CPython`.
+  focuses on :term:`CPython`.
 * Behaviour can vary across operating systems, especially when talking about
   I/O or multi-threading.
 * You should always find the hot spots in your program *before* attempting to
diff --git a/Lib/idlelib/NEWS.txt b/Lib/idlelib/NEWS.txt
index 5caa98e3fcc9b..ac8570701e3fa 100644
--- a/Lib/idlelib/NEWS.txt
+++ b/Lib/idlelib/NEWS.txt
@@ -6,7 +6,7 @@ Released on 2019-12-16?
 bpo-38943: Fix autocomplete windows not always appearing on some
 systems.  Patch by Johnny Najera.
 
-bpo-38944: Excape key now closes IDLE completion windows.  Patch by
+bpo-38944: Escape key now closes IDLE completion windows.  Patch by
 Johnny Najera.
 
 bpo-38862: 'Strip Trailing Whitespace' on the Format menu removes extra
diff --git a/Lib/tkinter/tix.py b/Lib/tkinter/tix.py
index d9c097a77cdd1..ac545502e45c3 100644
--- a/Lib/tkinter/tix.py
+++ b/Lib/tkinter/tix.py
@@ -1890,7 +1890,7 @@ def size_column(self, index, **kw):
         containing the current size setting of the given column.  When
         option-value pairs are given, the corresponding options of the
         size setting of the given column are changed. Options may be one
-        of the follwing:
+        of the following:
               pad0 pixels
                      Specifies the paddings to the left of a column.
               pad1 pixels
@@ -1915,7 +1915,7 @@ def size_row(self, index, **kw):
         When no option-value pair is given, this command returns a list con-
         taining the current size setting of the given row . When option-value
         pairs are given, the corresponding options of the size setting of the
         given row are changed. Options may be one of the follwing:
               pad0 pixels
                      Specifies the paddings to the top of a row.
               pad1 pixels
@@ -1915,7 +1915,7 @@ def size_row(self, index, **kw):
         taining the current size setting of the given row . When option-value
         pairs are given, the corresponding options of the size setting of the
-        given row are changed. Options may be one of the follwing:
+        given row are changed. Options may be one of the following:
               pad0 pixels
                      Specifies the paddings to the top of a row.



More information about the Python-checkins mailing list